summaryrefslogtreecommitdiffstats
path: root/sbin/fsck_ffs/inode.c
diff options
context:
space:
mode:
authorpjd <pjd@FreeBSD.org>2006-10-31 22:06:56 +0000
committerpjd <pjd@FreeBSD.org>2006-10-31 22:06:56 +0000
commit1fff821e2de5fd21ef549a021d018c83de7776e8 (patch)
tree5aa5dca4042a8cf53b45dc5c45fa5dd8fdbdf32f /sbin/fsck_ffs/inode.c
parentaaa4c16f6734f951c5260123c5c45a059bee0128 (diff)
downloadFreeBSD-src-1fff821e2de5fd21ef549a021d018c83de7776e8.zip
FreeBSD-src-1fff821e2de5fd21ef549a021d018c83de7776e8.tar.gz
Implements gjournal support. If file system has gjournal support enabled
and -p flag was given perform fast file system checking (bascially only garbage collecting of orphaned objects). Rename bread() to blread() and bwrite() to blwrite() as we now link to the libufs library, which also implement functions with that names. Sponsored by: home.pl
Diffstat (limited to 'sbin/fsck_ffs/inode.c')
-rw-r--r--sbin/fsck_ffs/inode.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sbin/fsck_ffs/inode.c b/sbin/fsck_ffs/inode.c
index e470f99..b41d843 100644
--- a/sbin/fsck_ffs/inode.c
+++ b/sbin/fsck_ffs/inode.c
@@ -329,10 +329,10 @@ getnextinode(ino_t inumber)
lastinum += fullcnt;
}
/*
* If bread returns an error, it will already have zeroed
* out the buffer, so we do not need to do so here.
*/
- (void)bread(fsreadfd, inodebuf, dblk, size);
+ (void)blread(fsreadfd, inodebuf, dblk, size);
nextinop = inodebuf;
}
dp = (union dinode *)nextinop;
@@ -329,10 +329,10 @@ getnextinode(ino_t inumber)
}
/*
- * If bread returns an error, it will already have zeroed
+ * If blread returns an error, it will already have zeroed
* out the buffer, so we do not need to do so here.
*/
OpenPOWER on IntegriCloud